@@ -413,4 +413,44 @@ def get_game_owner_type_by_id(gameID):
     API_JSON = json.loads(API_CONTENT)
     return API_JSON['data'][0]['creator']['type']
   except KeyError:
-    return 'Invalid PlaceID'
\ No newline at end of file
+    return 'Invalid PlaceID'
+def get_group_description_by_id(groupID):
+  try:
+    API_URL = f"https://groups.roblox.com/v1/groups/{groupID}"
+    API_CONTENT = requests.get(API_URL).text
+    API_JSON = json.loads(API_CONTENT)
+    return API_JSON['description']
+  except KeyError:
+    return 'Invalid GroupID'
+def get_group_name_by_id(groupID):
+  try:
+    API_URL = f"https://groups.roblox.com/v1/groups/{groupID}"
+    API_CONTENT = requests.get(API_URL).text
+    API_JSON = json.loads(API_CONTENT)
+    return API_JSON['name']
+  except KeyError:
+    return 'Invalid GroupID'
+def get_group_owner_by_id(groupID):
+  try:
+    API_URL = f"https://groups.roblox.com/v1/groups/{groupID}"
+    API_CONTENT = requests.get(API_URL).text
+    API_JSON = json.loads(API_CONTENT)
+    return API_JSON['owner']['name']
+  except KeyError:
+    return 'Invalid GroupID'
+def get_group_owner_display_by_id(groupID):
+  try:
+    API_URL = f"https://groups.roblox.com/v1/groups/{groupID}"
+    API_CONTENT = requests.get(API_URL).text
+    API_JSON = json.loads(API_CONTENT)
+    return API_JSON['owner']['displayName']
+  except KeyError:
+    return 'Invalid GroupID'
+def get_group_owner_username_by_id(groupID):
+  try:
+    API_URL = f"https://groups.roblox.com/v1/groups/{groupID}"
+    API_CONTENT = requests.get(API_URL).text
+    API_JSON = json.loads(API_CONTENT)
+    return API_JSON['owner']['username']
+  except KeyError:
+    return 'Invalid GroupID'
